function [rho, c, eta, lambda, cp, gamma] = air_constants(T)
%AIR_CONSTANTS - Calculate properties of air at given temperature
% Input:
%   T - equilibrium temperature [Celsius]
% Output:
%	rho - equilibrium density [kg/m^3]
%	c - speed of sound [m/s]
%	eta - dynamic viscosity [kg/s/m]
%	lambda - thermal conductivity [cal/(m s K)]
%	cp - heat capacity at constant pressure [cal/kg/K]
%	gamma - heat capacity ratio cp/cv [-]
%
%	Copyright Peter Rucz, 2014.

rho =   1.2929*(1-0.0037*T);         % air density [kg/m^3]
c =     331.45*(1+0.0018*T);         % sound velocity [m/s]
eta =   1.708e-5*(1 + 0.0029*T);     % air dynamic viscosity [kg/s/m]
lambda = 5.77e-3*(1 + 0.0033*T);     % air thermal conductivity [cal/msK]
cp =    240.0;                       % heat capacity at const p in cal/kgK
gamma =  1.402;                      % heat capacity ratio cp/cv

end % of air_constants
